#!/bin/sh

# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# 5724-I04 (C) COPYRIGHT International Business Machines Corp., 1997,2006
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

# ifix launcher
thisHostname=`hostname -s`
thisDir=`dirname "$0"`
errorsduringinstall=0

if [ ! "$2" ] 
then
  if [  -f ./LI71709.sh ]
 then
 echo "Ifix_LI71709: WVS Ifix LI71709 Installer command syntax: "
 echo "  "
 echo " to install ifix  syntax: ifix_LI71709.sh  -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_LI71709.sh -uninstall "
 echo " "
 exit -1
 fi
fi

if [ $# -eq 0 ]
then
 echo "Ifix_LI71709: WVS Ifix LI71709 Installer command syntax: "
 echo " to install ifix  syntax: ifix_LI71709 -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_LI71709.sh -uninstall "
 echo " "
 exit -1
fi

if [ -f /opt/WebSphere/AppServer/bin/setupCmdLine.sh ]
then
   source /opt/WebSphere/AppServer/bin/setupCmdLine.sh
fi
   
   
if [ ! "$WAS_HOME" ] ; then
   echo "Ifix_LI71709: Please run WebSphere Application Server's setupCmdLine.sh to setup"
   echo "         the WAS Command line environment"
  exit -1
fi

if [ ! "$WVS_ROOT" ] ; then
   echo "Ifix_LI71709: Please configure WebSphere Voice Server wvs.setenv according"
   echo "         to the WVS InfoCenter "
  exit -1
fi


isInstallOption=false
isUnInstallOption=false
nonJavaOptionCount=1
for option in "$@" ; do
  if [ "$option" = "-install" ] ; then
     isInstallOption=true
  else
     if [ "$option" = "-uninstall" ] ; then
        isUnInstallOption=true
     fi
  fi
done

if [ "$isInstallOption" = "true" ] ; then
  if [ -f $WVS_ROOT/ifix/LI71709/engine.bak ] ; then
    echo "Ifix_LI71709: Ifix LI71709 is applied, please uninstall before trying to reinstall ifix"
    exit -1
  fi
fi

if [ "$isInstallOption" = "true" ] ; then
 # Check that the ifix files are found
 echo "Ifix_LI71709: Checking for ifix files ..."
  if [ -f $thisDir/engine ] ; then
    if [ -f $thisDir/engine ] ; then
      echo "Ifix_LI71709: Ifix files found.. proceeding to install ifix"
      mkdir -p $WVS_ROOT/ifix/LI71709
      cp -p $thisDir/LI71709.sh $WVS_ROOT/ifix/ifix_LI71709.sh
      
      cp -p $WVS_ROOT/ViaVoice/bin/engine $WVS_ROOT/ifix/LI71709/engine.bak
      cp -p $WVS_ROOT/ViaVoice/bin/libvvgp.so $WVS_ROOT/ifix/LI71709/libvvgp.so.bak
            
      echo "Ifix_LI71709: Stopping WebSphere Application Server"
      $WAS_HOME/bin/stopServer.sh server1
      echo $?
      if [ "$?" = "246" -o "$?" = "0" ] ; then
         echo "Ifix_LI71709: Application Server stopped successful, proceeding to install ifix"
      else
         echo "Ifix_LI71709: Application Server reported failure during stopping. Ifix installation will not continue"
         rm -rf $WVS_ROOT/ifix/LI71709
         exit -1
      fi      
      
      cp -fbp $thisDir/engine $WVS_ROOT/ViaVoice/bin/.
      cp -fbp $thisDir/libvvgp.so $WVS_ROOT/ViaVoice/bin/.
      
      chmod 755 $WVS_ROOT/ViaVoice/bin/engine
      chmod 755 $WVS_ROOT/ViaVoice/bin/libvvgp.so	  

      echo "Ifix_LI71709: Starting WebSphere Application Server"
      $WAS_HOME/bin/startServer.sh server1 -quiet
      if [ "$?" = "111" -o "$?" = "0" ] ; then
         echo "Ifix_LI71709: Application Server started successful, proceeding to install ifix"
      else
         echo "Ifix_LI71709: Application Server reported failure during starting. Ifix installation was not successful. Please uninstall"
         exit -1
      fi

      echo "Ifix_LI71709: Ifix is now applied, please reboot the system"
      
    else
      echo "Ifix_LI71709: Ifix files missing, please be sure this script is in same directory as the binary files" 
    fi
  fi
  cp -fp $thisDir/LI71709.log $WVS_ROOT/log/.
fi

if [ "$isUnInstallOption" = "true" ] ; then
 # Check that the ifix backup files are found
 echo "Ifix_LI71709: Checking for ifix backup files ..."
  if [ -f $WVS_ROOT/ifix/LI71709/engine.bak ] ; then
    if [ -f $WVS_ROOT/ifix/LI71709/engine.bak ] ; then
      echo "Ifix_LI71709: Ifix backup files found.. proceeding to un-install ifix"

      
      echo "Ifix_LI71709: Stopping WebSphere Application Server"
      $WAS_HOME/bin/stopServer.sh server1
      echo $?
      if [ "$?" = "246" -o "$?" = "0" ] ; then
         echo "Ifix_LI71709: Application Server stopped successful, proceeding to uninstall ifix"
      else
         echo "Ifix_LI71709: Application Server reported failure during stopping. Ifix uninstallation will not continue"
         rm -rf $WVS_ROOT/ifix/LI71709
         exit -1
      fi
      
      cp -fp $WVS_ROOT/ifix/LI71709/engine.bak  $WVS_ROOT/ViaVoice/bin/engine
      cp -fp $WVS_ROOT/ifix/LI71709/libvvgp.so.bak  $WVS_ROOT/ViaVoice/bin/libvvgp.so
	  
      chmod 755 $WVS_ROOT/ViaVoice/bin/engine
      chmod 755 $WVS_ROOT/ViaVoice/bin/libvvgp.so	  
          
      echo "Ifix_LI71709: Starting WebSphere Application Server"
      $WAS_HOME/bin/startServer.sh server1 -quiet
      if [ "$?" = "111" -o "$?" = "0" ] ; then
         echo "Ifix_LI71709: Application Server started successful, proceeding to uninstall ifix"
      else
         echo "Ifix_LI71709: Application Server reported failure during starting. Ifix uninstallation was not successful. Please contact support"
         exit -1
      fi
       

      echo "Ifix_LI71709: Ifix is now uninstalled, please reboot the system"
      echo "Ifix_LI71709:  Please remove the $WVS_ROOT/ifix/LI71709 directory before attempting a subsequent install of this ifix."
      
    else
      echo "Ifix_LI71709: Ifix backup files missing, uninstall not performed"
    fi
  else
    echo "Ifix_LI71709: Ifix backup files missing, uninstall not performed"
  fi
fi
exit $?
